@@ -53,7 +53,6 @@ use G::DB::BDB;
 use G::Seq::AminoAcid;
 use G::Seq::Codon;
 use G::Seq::Consensus;
-use G::Seq::Eliminate;
 use G::Seq::FreeEnergy;
 use G::Seq::GCskew;
 use G::Seq::Operon;
@@ -63,23 +62,19 @@ use G::Seq::PatSearch;
 use G::Seq::Tandem;
 use G::Seq::Util;
 use G::Seq::Markov;
-use G::Seq::ORF;
 use G::Seq::Align;
 use G::Seq::Usage;
 use G::Seq::COMGA;
 use G::Seq::GenomeMap;
 use G::Seq::ImaGene;
 use G::Tools::Graph;
-use G::Tools::H2v;
 use G::Tools::Mapping;
 use G::Tools::Blast;
 use G::Tools::Fasta;
 use G::Tools::Alignment;
 use G::Tools::HMMER;
 use G::Tools::Repeat;
-use G::Tools::EPCR;
 use G::Tools::SIM4;
-use G::Tools::PBS;
 use G::Tools::Cap3;
 use G::Tools::COGs;
 use G::Tools::GPAC;
@@ -101,7 +96,6 @@ use G::SystemsBiology::DotE;
 use G::System::BAS;
 use G::System::GEMS;
 use G::System::COMGA;
-use G::System::STeP;
 use G::System::CHI;
 use G::System::ReL8;
 use G::System::FuncD;
@@ -115,7 +109,6 @@ our @EXPORT;
 push(@EXPORT, @G::Seq::AminoAcid::EXPORT);
 push(@EXPORT, @G::Seq::Codon::EXPORT);
 push(@EXPORT, @G::Seq::Consensus::EXPORT);
-push(@EXPORT, @G::Seq::Eliminate::EXPORT);
 push(@EXPORT, @G::Seq::FreeEnergy::EXPORT);
 push(@EXPORT, @G::Seq::GCskew::EXPORT);
 push(@EXPORT, @G::Seq::Operon::EXPORT);
@@ -125,23 +118,19 @@ push(@EXPORT, @G::Seq::PatSearch::EXPORT);
 push(@EXPORT, @G::Seq::Tandem::EXPORT);
 push(@EXPORT, @G::Seq::Util::EXPORT);
 push(@EXPORT, @G::Seq::Markov::EXPORT);
-push(@EXPORT, @G::Seq::ORF::EXPORT);
 push(@EXPORT, @G::Seq::Align::EXPORT);
 push(@EXPORT, @G::Seq::Usage::EXPORT);
 push(@EXPORT, @G::Seq::COMGA::EXPORT);
 push(@EXPORT, @G::Seq::ImaGene::EXPORT);
 push(@EXPORT, @G::Seq::GenomeMap::EXPORT);
 push(@EXPORT, @G::Tools::Graph::EXPORT);
-push(@EXPORT, @G::Tools::H2v::EXPORT);
 push(@EXPORT, @G::Tools::Mapping::EXPORT);
 push(@EXPORT, @G::Tools::Blast::EXPORT);
 push(@EXPORT, @G::Tools::Fasta::EXPORT);
 push(@EXPORT, @G::Tools::Alignment::EXPORT);
 push(@EXPORT, @G::Tools::HMMER::EXPORT);
 push(@EXPORT, @G::Tools::Repeat::EXPORT);
-push(@EXPORT, @G::Tools::EPCR::EXPORT);
 push(@EXPORT, @G::Tools::SIM4::EXPORT);
-push(@EXPORT, @G::Tools::PBS::EXPORT);
 push(@EXPORT, @G::Tools::Cap3::EXPORT);
 push(@EXPORT, @G::Tools::COGs::EXPORT);
 push(@EXPORT, @G::Tools::GPAC::EXPORT);
@@ -703,6 +692,49 @@ G - G-language Genome Analysis Environment core interface module
 
 =cut
 
+
+=head2 $gb->around_startcodon()
+
+   Name: $gb->around_startcodon()   -   get the sequence around the startcodon of the given CDS
+
+   Description:
+         Given a CDS ID, lengths before startcodon and after start codon, 
+         returns the sequence around of start codon.
+
+         eg. $gb->around_startcodon('FEATURE5239', 100, 100); 
+             # returns 100 bp sequence before and after the start codon of 'CDS1',
+             # including the start codon itself
+
+   Options:
+         Optional Fourth argument containing a string "without" returns only the sequence
+         before and after the start codon, and without the stat codon itself.
+         eg. $gb->around_startcodon('FEATURE5239', 100, 100, "without");
+
+=cut
+
+
+
+=head2 $gb->around_stopcodon()
+
+   Name: $gb->around_stopcodon()   -   get the sequence around the stopcodon of the given CDS
+
+   Description:
+         Given a CDS ID, lengths before stopcodon and after stop codon, 
+         returns the sequence around of stop codon.
+
+         eg. $gb->around_stopcodon('FEATURE5239', 100, 100); 
+             # returns 100 bp sequence before and after the stop codon of 'CDS1',
+             # including the stop codon itself
+
+   Options:
+         Optional Fourth argument containing a string "without" returns only the sequence
+         before and after the stop codon, and without the stat codon itself.
+         eg. $gb->around_stopcodon('FEATURE5239', 100, 100, "without");
+
+=cut
+
+
+
 =head2 $gb->get_exon()
 
    Name: $gb->get_exon()   -   get a list of exon sequences of the given CDS
