@@ -32,12 +32,12 @@
 package G::DynamicLoader;
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK @INC $AUTOLOAD);
 use File::Find;
 
 require Exporter;
 
-@ISA = qw(Exporter AutoLoader);
+our @ISA = qw(Exporter);
+our @EXPORT;
 
 BEGIN{
 
@@ -48,7 +48,6 @@ BEGIN{
     }
     unshift(@INC, $path);
 
-
     no strict 'refs';
     
 #1. open plug-in folder
@@ -59,11 +58,10 @@ BEGIN{
 	sub {
 	    my $dir = $File::Find::name;
 	    my $dirpath = $dir;
-#	    print $dir, "\n";return;
+
 	    if(-d $dir){
 		$dir =~ s/^$path$/\.\//g;
 		$dir =~ s/^$path\//\.\//g;
-#		print $dir, " $path\n";return;
 		
 		my $file;
 		opendir(DIR, $dirpath) || die "can't opendir $dir: $!"; 
@@ -77,7 +75,7 @@ BEGIN{
 		    if($file=~/(.+)\.pm$/){
 			next if ($file =~ /^\.\#/);
 			my $dirname= $dir.$1;
-#			print $dirname, "\n";
+
 			eval "use $dirname";
 			
 			if ($@) { warn "$@"}
@@ -95,8 +93,6 @@ BEGIN{
 
 1;
 
-__END__
-
 
 
 
