@@ -53,7 +53,7 @@ use File::Basename;
 use File::ShareDir ':ALL';
 
 our @ISA = qw(G::IO::Handler G::IO::GenBankI G::IO::GenBankO G::DB::Handler);
-our $VERSION = '1.7.4';
+our $VERSION = '1.7.5';
 
 #::::::::::::::::::::::::::::::
 #          Perldoc
@@ -149,7 +149,7 @@ sub new {
 	}elsif ($opt =~ /bioperl/){
 	    $bioperl = 1;
 	    $format = 'bioperl';
-	}elsif ($opt =~ /longest ORF annotation/){
+	}elsif ($opt =~ /longest orf/){
 	    $longest_ORF_annotation = 1;
 	}elsif ($opt =~ /glimmer annotation/){
 	    $glimmer_annotation = 1;
