@@ -34,14 +34,11 @@ package G::IO::FastaI;
 use G;
 use strict;
 use G::Messenger;
-require G::Prelude;
+require G::IO::Handler;
 require G::IO::GenBankO;
 
-use vars qw($VERSION @ISA @INC $AUTOLOAD);
+our @ISA = qw(G::IO::Handler G::IO::GenBankO);
 
-@ISA = qw(G::Prelude G::IO::GenBankO);
-
-$VERSION = '1.0';
 
 #::::::::::::::::::::::::::::::
 #     Let the code begin...
