@@ -6,8 +6,6 @@
 #     Copyright (C) 2001-2007 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
-#   $Id: Messenger.pm,v 1.5 2002/05/27 21:17:35 gaou Exp $
-#
 # G-language GAE is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public
 # License as published by the Free Software Foundation; either
@@ -40,12 +38,10 @@ if ('MSWin32' eq $^O){
     eval(require Image::Size);
 }
 
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
 require Exporter;
 
-@ISA = qw(Exporter AutoLoader);
-@EXPORT = qw(
+our @ISA = qw(Exporter);
+our @EXPORT = qw(
 	     msg_interface
 	     msg_ask_interface
 	     msg_send
@@ -60,8 +56,6 @@ require Exporter;
 	     p
 	     puts
 );
-$VERSION = '0.20';
-
 
 #::::::::::::::::::::::::::::::
 #          Variables
