@@ -53,6 +53,22 @@ my @score_path_matrix;
 
 __DATA__
 
+#:::::::::::::::::::::::::::::::::
+#       Perldoc
+#:::::::::::::::::::::::::::::::::
+
+=head1 NAME
+
+  G::Seq::Align - Analysis methods related to sequence alignment
+
+=head1 DESCRIPTION
+
+    This class is a part of G-language Genome Analysis Environment, 
+    collecting sequence analysis methods related to GC skew.
+
+=cut
+
+
 #::::::::::::::::::::::::::::::
 #        Methods Start
 #::::::::::::::::::::::::::::::
@@ -273,34 +289,3 @@ sub diffseq{
 
 1;
 
-__END__
-# Below is the stub of documentation for your module. You better edit it!
-
-=head1 NAME
-
-G::Seq::Align - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  blah blah blah
-
-=head1 DESCRIPTION
-
-Stub documentation for G::Seq::Align was created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 AUTHOR
-
-A. U. Thor, a.u.thor@a.galaxy.far.far.away
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
-
-
-
