@@ -37,35 +37,39 @@ use G::Tools::GPAC;
 use G::DB::SDB;
 use strict;
 
-BEGIN{
-    eval "use GD;";
-    if($@){ warn "$@" };
-    eval "use SVG;";
-    if($@){ warn "$@" };
-}
-
+use GD;
+use SVG;
 use Cwd;
 
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
 use SelfLoader;
 
 require Exporter;
 
-@ISA = qw(Exporter AutoLoader);
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
+our @ISA = qw(Exporter);
+our @EXPORT = qw(
 		COMGA_table_maker
 		COMGA_correlation
 	     );
-$VERSION = '0.01';
-
 
 
 __DATA__
 
+#:::::::::::::::::::::::::::::::::
+#       Perldoc
+#:::::::::::::::::::::::::::::::::
+
+
+=head1 NAME
+
+  G::Seq::COMGA - Analysis methods related to comparative genome analysis
+
+=head1 DESCRIPTION
+
+    This class is a part of G-language Genome Analysis Environment, 
+    collecting sequence analysis methods related to GC skew.
+
+=cut
+
 #::::::::::::::::::::::::::::::
 #        Methods Start
 #::::::::::::::::::::::::::::::
@@ -407,40 +411,6 @@ sub COMGA_table_maker{
 }
 
 
-sub DESTROY {
-    my $self = shift;
-}
-
 
 1;
 
-__END__
-
-# Below is the stub of documentation for your module. You better edit it!
-
-=head1 NAME
-
-G::Seq::COMGA - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use G::Seq::COMGA;
-  blah blah blah
-
-=head1 DESCRIPTION
-
-Stub documentation for G::Seq::COMGA was created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 AUTHOR
-
-A. U. Thor, a.u.thor@a.galaxy.far.far.away
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
