@@ -29,6 +29,7 @@ package G::Seq::GCskew;
 use SubOpt;
 use G::Messenger;
 use G::Tools::Graph;
+use G::Seq::Primitive;
 
 use strict;
 use Statistics::Descriptive;
@@ -322,10 +323,10 @@ sub leading_strand {
     if ($ori > $ter){
 	$seq1  = substr($gb->{SEQ}, $ori);
 	$seq1 .= substr($gb->{SEQ}, 0, $ter);
-	$seq2  = G::Seq::Util::_complement(substr($gb->{SEQ}, $ter, $ori - $ter));
+	$seq2  = complement(substr($gb->{SEQ}, $ter, $ori - $ter));
     }else{
 	$seq1 = substr($gb->{SEQ}, $ori, $ter - $ori);
-	$seq2 = G::Seq::Util::_complement( substr($gb->{SEQ}, $ter) . substr($gb->{SEQ}, 0, $ori) );
+	$seq2 = complement( substr($gb->{SEQ}, $ter) . substr($gb->{SEQ}, 0, $ori) );
     }
     
     return ($seq1, $seq2);
@@ -587,11 +588,11 @@ sub cum_gcskew {
    intergenic regions, and the third codon.
 
  Usage: 
-    1 = genomicskew(G instance);
+    1 = genomicskew($genome);
 
  Options:
    -divide      window number to divide into (default: 250)
-   -At          1 when observing AT skew instead of GC skew (default: 0)
+   -at          1 when observing AT skew instead of GC skew (default: 0)
    -output      f for file output in directory "data", 
                 g for graph output in directory "graph",
                 show for graph output and display (default: "show")
@@ -886,7 +887,7 @@ sub gcwin  {
 
 
 
-Sub query_strand {
+sub query_strand {
     opt_default(direction=>'direct');
     my @args = opt_get(@_);
     my $gb = shift @args;
