@@ -25,7 +25,7 @@
 # 
 #END_HEADER
 #
-# written by Kazuharu Arakawa <gaou@g-language.org> at
+# written by Kazuharu Arakawa <gaou@sfc.keio.ac.jp> at
 # G-language Project, Institute for Advanced Biosciences, Keio University.
 #
 
@@ -889,21 +889,26 @@ sub genome_map2 {
     NULL = genome_map($gb);
 
  Options:
-    -output    "g" for graph, "show" for display (default: "show") 
+    -width          image width (default: 8192)
+    -height         image height (default: 8192)
+    -output         "g" for graph, "show" for display (default: "show") 
+    -datafilename   coordinate file name (default: "data.coord")
 
   Author: 
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
-   20070523-01 initial posting
+   20070628-01 added -datafilename option
+   20070623-01 initial posting
 
 =cut
 
 sub genome_map3 {
-    &opt_default(output=>"show", width=>8196, height=>8196);
+    &opt_default(output=>"show", width=>8192, height=>8192, datafilename=>"data.coord");
     my @args = opt_get(@_);
     my $gb = opt_as_gb(shift @args);
     my $acnum = $gb->{LOCUS}->{id};
+    my $datafilename = opt_val("datafilename");
     my $output = opt_val("output");
     my $filename;
     my $topmargin = 50;
@@ -927,7 +932,7 @@ sub genome_map3 {
 
     mkdir ("graph", 0777);
     mkdir ("data", 0777);
-    open(OUT, '>' . 'data/' . $gb->{LOCUS}->{id} . '.coord') || die($!);
+    open(OUT, '>' . 'data/' . $datafilename) || die($!);
 
     # GD constant
     my $im = new GD::Image($width, $height);
@@ -1181,7 +1186,7 @@ sub genome_map3 {
 
 
   Author: 
-    Kazuharu Gaou Arakawa (gaou@sfc.keio.ac.jp)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
     20060714 added -window option
