@@ -32,28 +32,38 @@ use SubOpt;
 use G::Messenger;
 
 use GD;
-
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 
 use SelfLoader;
 
 require Exporter;
 
-@ISA = qw(Exporter AutoLoader);
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
-	     find_tandem
-	     foreach_tandem
-	     _print_tandem
-	     graphical_LTR_search
+our @ISA = qw(Exporter);
+our @EXPORT = qw(
+		 find_tandem
+		 foreach_tandem
+		 _print_tandem
+		 graphical_LTR_search
 );
 
 
 __DATA__
 
+#::::::::::::::::::::::::::::::
+#        Perldoc
+#::::::::::::::::::::::::::::::
+
+=head1 NAME
+
+  G::Seq::Tandem - Sequence analysis methods related to tandem repeats.
+
+=head1 DESCRIPTION
+
+           This class is a part of G-language Genome Analysis Environment,
+           collecting basic sequence analysis methods.
+
+=cut
+
 #::::::::::::::::::::::::::::::
 #        Methods Start
 #::::::::::::::::::::::::::::::
