@@ -35,27 +35,25 @@ use SubOpt;
 use G::Messenger;
 use G::Seq::Primitive;
 use G::Tools::Graph;
+use G::IO;
+use G::IO::Annotation;
 
 use strict;
 use Cwd;
 use SelfLoader;
 
-
 require Exporter;
 
 our @ISA = qw(Exporter);
 
 our @EXPORT = qw(
 		 find_king_of_gene
-		 atcgcon
-		 cds_echo
-		 print_gene_function_list
 		 seqinfo
-		 maskseq
-		 pasteseq
+		 longest_ORF
 		 molecular_weight
 		 view_cds
 		 oligomer_translation
+		 filter_cds_by_atg
 		 );
 
 
@@ -75,54 +73,6 @@ our @EXPORT = qw(
 
 =cut
 
-#::::::::::::::::::::::::::::::
-#        Constants
-#::::::::::::::::::::::::::::::
-
-my %COG_fcode = (
-		 J=>"Translation, ribosomal structure and biogenesis",
-		 K=>"Transcription",
-		 L=>"DNA replication, recombination and repair",
-		 D=>"Cell division and chromosome partitioning",
-		 O=>"Posttranslational modification, protein turnover, chaperones",
-		 M=>"Cell envelope biogenesis, outer membrane",
-		 N=>"Cell motility and secretion",
-		 P=>"Inorganic ion transport and metabolism",
-		 T=>"Signal transduction mechanisms",
-		 C=>"Energy production and conservation",
-		 G=>"Carbohydrate transport and metabolism",
-		 E=>"Amino acid transport and metabolism",
-		 F=>"Nucleotide transport and metabolism",
-		 H=>"Coenzyme metabolism",
-		 I=>"Lipid metabolism",
-		 Q=>"Secondary metabolites biosynthesis, transport and catabolism",
-		 R=>"General function prediction only",
-		 S=>"Function unknown",
-		 '-'=>"Non COG"
-		 );
-
-my %COG_fcolor = (
-		  J=>"plum",
-		  K=>"fuchsia",
-		  L=>"pink",
-		  D=>"lightgreen",
-		  O=>"green",
-		  M=>"khaki",
-		  N=>"greenyellow",
-		  P=>"darkkhaki",
-		  T=>"cyan",
-		  C=>"blue",
-		  G=>"mediumturquoise",
-		  E=>"lightskyblue",
-		  F=>"mediumpurple",
-		  H=>"aqua",
-		  I=>"blueviolet",
-		  Q=>"lightskyblue",
-		  R=>"gainsboro",
-		  S=>"darkgrey",
-		  '-'=>"aliceblue"
-		  );
-
 __DATA__
 
 #::::::::::::::::::::::::::::::
@@ -190,6 +140,42 @@ sub seqinfo {
 }
 
 
+=head2 longest_ORF
+
+  Name: longest_ORF   -   find longest ORFs within a given sequence
+
+  Description:
+    This method searches for putative coding regions by longest ORF
+    method, the longest spanning sequence seqment starting from "atg"
+    and ending with "tag", "taa", or "tgg" in the same coding frame.
+
+    Returning object is the G-language genome data object, so in 
+    Shell, typing the following after calling this method shows the
+    list of putative ORFs:
+         $annotated_data->find(-type=>"CDS");
+
+ Usage: 
+    $genome = longest_ORF($sequence);
+
+ Options:
+   none
+
+  Author: Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+
+  History:
+    20070914-01 rewrite, and moved from G::Seq::ORF
+    20010829-01 initial posting
+
+=cut
+
+
+sub longest_ORF{
+    my $this = opt_as_gb(shift @_);
+    my $new = new G::IO("blessed");
+    annotate_with_LORF($new, $this);
+
+    return $new;
+}
 
 =head2 molecular_weight
 
@@ -267,209 +253,6 @@ sub find_king_of_gene{
 }
 
 
-#atcgcon ver.20010623-01
-#scripting by Koya Mori(mory@g-language.org)
-#This program counts bases in CDS.
-#(hash result)=&bun(pointer Genome,  boolean debug);
-sub atcgcon{
-    &opt_default(output=>"stdout",filename=>"cds_info.csv");
-    my @args=opt_get(@_);
-
-    my $gb=opt_as_gb(shift @args);
-    my $output=opt_val("output");
-    my $filename=opt_val("filename");
-    my $start;
-    my $end;
-    my $seq;
-    my $num=1;
-    my %hash;
-
-
-    foreach($gb->feature()){
-	if($gb->{"FEATURE$num"}->{type} eq 'CDS'){
-	    $start=$gb->{"FEATURE$num"}->{start};
-	    $end=$gb->{"FEATURE$num"}->{end};
-	    $seq=$gb->getseq($start-1,$end-1);
-	    $hash{a} += $seq =~tr/a/a/;
-	    $hash{t} += $seq =~tr/t/t/;
-	    $hash{g} += $seq =~tr/g/g/;
-	    $hash{c} += $seq =~tr/c/c/;
-	    $hash{total}+=length($seq);
-	}
-	$num++;
-    }
-
-    if($output eq "stdout"){
-	&msg_send(sprintf("total:\t%10d base\n",$hash{total}));
-	&msg_send(sprintf("a:\t%10d / %2.2f\%\n", $hash{a}, 100.0*$hash{a}/$hash{total}));
-	&msg_send(sprintf("t:\t%10d / %2.2f\%\n", $hash{t}, 100.0*$hash{t}/$hash{total}));
-	&msg_send(sprintf("c:\t%10d / %2.2f\%\n", $hash{c}, 100.0*$hash{c}/$hash{total}));
-	&msg_send(sprintf("g:\t%10d / %2.2f\%\n", $hash{g}, 100.0*$hash{g}/$hash{total}));
-	
-	&msg_send(sprintf("GC content:\t%.2f\%\n", 100.0*($hash{c} + $hash{g}) / $hash{total}));
-    }
-    if($output eq "f"){
-	open(FILE,">$filename");
-	printf FILE "total:\t%10d base\n",$hash{total};
-	printf FILE "a:\t%10d / %2.2f\%\n", $hash{a}, 100.0*$hash{a}/$hash{total};
-	printf FILE "t:\t%10d / %2.2f\%\n", $hash{t}, 100.0*$hash{t}/$hash{total};
-	printf FILE "c:\t%10d / %2.2f\%\n", $hash{c}, 100.0*$hash{c}/$hash{total};
-	printf FILE "g:\t%10d / %2.2f\%\n", $hash{g}, 100.0*$hash{g}/$hash{total};
-	
-	printf FILE "GC content:\t%.2f\%\n", 100.0*($hash{c} + $hash{g}) / $hash{total};
-	close(FILE);
-    }
-
-    return \%hash;
-}
-
-
-#cds_echo ver.20010623-01
-#scripting by Koya Mori(mory@g-language.org)
-#This program displayes CDS start and end positions.
-#(hash result)=&bun(pointer Genome,  boolean debug);
-sub cds_echo{
-    my $gb=opt_as_gb(shift);
-    my $start;
-    my $end;
-    my $i=1;
-
-    foreach($gb->feature()){
-        if($gb->{"FEATURE$i"}->{type} eq 'CDS'){
-	    if($gb->{"FEATURE$i"}->{direction} eq 'direct'){
-		$start = $gb->{"FEATURE$i"}->{start};
-		$end = $gb->{"FEATURE$i"}->{end};
-		&msg_send(sprintf("%d..%d\n",$start,$end));
-	    }
-	        
-	    elsif($gb->{"FEATURE$i"}->{direction} eq 'complement'){
-		$start = $gb->{"FEATURE$i"}->{end};
-		$end = $gb->{"FEATURE$i"}->{start};
-		&msg_send(sprintf("%d..%d\n",$start,$end));
-	    }
-	}
-	$i++;
-    }
-}
-
-
-#print_gene_function_list ver.20010718-01
-#Author: Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
-#1 = &print_gene_function_list (pointer G instance, string sequence)
-#This subroutine prints out the number of genes for each functions,
-#and the number of specified oligomers in each gene function groups.
-#The default for string sequence is 'gctggtgg'.
-sub print_gene_function_list {
-    my $gb = opt_as_gb(shift);
-    my $seq = shift;
-    $seq = 'gctggtgg' unless ($seq);
-    my $revseq = complement($seq);
-    my $i = 1;
-    my %chi;
-    my %cds;
-    my $key;
-
-    while(defined(%{$gb->{"CDS$i"}})){
-        my $id = $gb->{"CDS$i"}->{feature};
-        my ($function, $tmp) = split(/;/, $gb->{"FEATURE$id"}->{function}, 2);
-        my $cdsseq = $gb->get_cdsseq("CDS$i");
-        $cds{$function}++;
-        
-        my $iStart = -1;
-        while(0 <= ($iStart = index($cdsseq, $seq, $iStart +1))){
-            $chi{$function}++;
-        }
-        $iStart = -1;
-        while(0 <= ($iStart = index($cdsseq, $revseq, $iStart +1))){
-	    $chi{$function}++;
-	}
-        
-        $i++;
-    }
-    
-    &msg_send("=== $seq ===\n");
-    my $tot = 0;
-    foreach $key (sort keys %chi){
-        &msg_send(sprintf("%20s: %8d\n",$key, $chi{$key}));
-        $tot += $chi{$key};
-    }
-    
-    &msg_send("total: $tot\n\n");
-    
-    
-    &msg_send("=== CDS ===\n");
-    $tot = 0;
-    foreach $key (sort keys %cds){
-        next if ($key !~ /[a-z]/);
-        &msg_send(sprintf("%20s: %8d\n", $key, $cds{$key}));
-        $tot += $cds{$key};
-    }
-    
-    &msg_send("total: $tot\n");
-
-    return 1;
-}
-
-
-sub maskseq{
-    &opt_default(pattern=>"",start=>1,end=>"");
-    my @args=opt_get(@_);
-
-    my $gb=opt_as_gb(shift @args);
-    my $seq=\$gb->{SEQ};
-    my $start=opt_val("start");
-    my $end=opt_val("end");
-    my $pat=opt_val("pattern");
-    my $masked;
-    my $null;
- 
-
-    $$seq=~tr/ \n[0-9]//d;
-    $$seq=~tr/A-Z/a-z/;
-    
-    $end=length($$seq) if($end eq "");
-
-    for(my $i=0;$i<length($pat);$i++){
-	$null.="n";
-    }
-
-    if($pat){
-	$masked=substr($$seq,$start-1,$end-$start+1);
-	$masked=~s/$pat/$null/g;
-	substr($$seq,$start-1,$end-$start+1)=$masked;
-    }
-    else{
-	$masked=substr($$seq,$start-1,$end-$start+1);
-	$masked=~tr/a-zA-Z/n/;
-	substr($$seq,$start-1,$end-$start+1)=$masked;
-    }
-
-    return $seq;
-}
-
-
-sub pasteseq{
-    &opt_default();
-    my @args=opt_get(@_);
-    
-    my $gb=opt_as_gb(shift);
-    my $seq=\$gb->{SEQ};
-    my $paste=shift @_;
-    my $pos=shift @_;
-    
-    $$seq=~tr/ \n[0-9]//d;
-    $$seq=~tr/A-Z/a-z/;
-    $$paste=~tr/A-Z/a-z/;
-
-    substr($$seq,$pos-1,0)=$$paste;
-
-    return $seq;
-}
-
-
-
-
-
 
 
 # oligomer_translation ver.20011103-01
@@ -559,6 +342,7 @@ sub oligomer_translation {
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+    20070914-01 code optimization
     20070707-01 moved to G::Seq::Util from G::Seq::GCskew
     20010906-01 initial posting
 
@@ -567,13 +351,15 @@ sub oligomer_translation {
 
 
 sub view_cds{
-    &opt_default(length=>100, filename=>"view_cds.png", 
+    opt_default(length=>100, filename=>"view_cds.png", 
 		  gap=>3, output=>"show", application=>"gimv");
     my @args = opt_get(@_);
     my $gb = opt_as_gb(shift @args);
-    my (@a, @t, @g, @c, @pos);
-    my $numcds = 0;
+    my $data = {};
+    my @pos;
+    my $numcds = scalar $gb->cds();
     my $i = 0;
+    my $gap = opt_val("gap");
     my $length = opt_val("length");
     my $filename = opt_val("filename");
     my $output = opt_val("output");
@@ -581,49 +367,23 @@ sub view_cds{
 
     $filename = "view_cds.csv" if ($output eq "f" &&
 				   opt_val("filename") eq "view_cds.png");
-    my $gap = opt_val("gap");
-
-    while(defined %{$gb->{"CDS$numcds"}}){ $numcds ++ }
-
-    for ($i = 0; $i < $length * 4 + 6 + $gap; $i++){
-	$a[$i] = 0;
-	$t[$i] = 0;
-	$g[$i] = 0;
-	$c[$i] = 0;
+    for my $nuc (qw/a t g c/){
+	for ($i = 0; $i < $length * 4 + 6 + $gap; $i++){
+	    $data->{$nuc}->[i] = 0;
+	}
     }
 
     foreach my $cds ($gb->cds()){
-	my $seq;
-	$seq  = $gb->before_startcodon($cds, $length);
-	$seq .= $gb->startcodon($cds);
-	$seq .= $gb->after_startcodon($cds, $length);
+	my $seq = $gb->around_startcodon($cds, $length, $length);
 	
 	for ($i = 0; $i < length($seq); $i ++){
-	    if     (substr($seq, $i, 1) eq 'a'){
-		$a[$i] += 100/$numcds;
-	    }elsif (substr($seq, $i, 1) eq 't'){
-		$t[$i] += 100/$numcds;
-	    }elsif (substr($seq, $i, 1) eq 'g'){
-		$g[$i] += 100/$numcds;
-	    }elsif (substr($seq, $i, 1) eq 'c'){
-		$c[$i] += 100/$numcds;
-	    }
-        }
-	
-	$seq  = $gb->before_stopcodon($cds, $length);
-	$seq .= $gb->stopcodon($cds);
-	$seq .= $gb->after_stopcodon($cds, $length);
-	
+	    $data->{substr($seq, $i, 1)}->[$i] += 100/$numcds;
+	}
+
+	$seq  = $gb->around_stopcodon($cds, $length, $length);
+
 	for ($i = 0; $i < length($seq); $i ++){
-	    if     (substr($seq, $i, 1) eq 'a'){
-		$a[$i + length($seq) + $gap] += 100/$numcds;
-	    }elsif (substr($seq, $i, 1) eq 't'){
-		$t[$i + length($seq) + $gap] += 100/$numcds;
-	    }elsif (substr($seq, $i, 1) eq 'g'){
-		$g[$i + length($seq) + $gap] += 100/$numcds;
-	    }elsif (substr($seq, $i, 1) eq 'c'){
-		$c[$i + length($seq) + $gap] += 100/$numcds;
-	    }
+	    $data->{substr($seq, $i, 1)}->[$i + length($seq) + $gap] += 100/$numcds;
 	}
     }
     
@@ -634,8 +394,9 @@ sub view_cds{
     if ($output eq "g" || $output eq "show"){
 	_UniMultiGrapher(
 			 \@pos, -x => "position", -y => "percentage",
-			 \@a, -x1=>"A", \@t, -x2=>"T",
-			 \@g, -x3=>"G", \@c, -x4=>"C",
+			 [@{$data->{a}}], [@{$data->{t}}], [@{$data->{g}}], [@{$data->{c}}],
+			 -x1=>"A", -x2=>"T",
+			 -x3=>"G", -x4=>"C",
 			 -filename => $filename,
 			 -title => "Base Contents Around Start/Stop Codons"
 			 );
@@ -653,4 +414,60 @@ sub view_cds{
 }
 
 
+
+
+
+=head2 filter_cds_by_atg
+
+  Name: filter_cds_by_atg   -   filter CDS by the presence of ATG near start codon
+
+  Description:
+    This method filters out the list of CDSs in a given genome, when
+    ATG is present near the start codon within the same coding frame.
+    Returns the list of CDSs that do not have nearby ATG, and sets
+    $genome->{$cds}->{on} to 0 for all CDSs that contain nearby ATG.
+
+ Usage: 
+    @list_of_feature_ids = filter_cds_by_atg($gb)
+
+ Options:
+   -upstream      length of upstream region (default:50)
+   -downstream    length of downstream region (default:50)
+   -codon         start codon to search (default: "atg")
+
+  Author: Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+          originally by Koya Mori, but re-written.
+
+  History:
+    20070914-01 rewrite by Kazuharu Arakawa. renamed and moved to G::Seq::Util
+    20010623-01 initial posting by Koya Mori as "eliminate_atg"
+
+=cut
+
+
+sub filter_cds_by_atg{
+    opt_default(upstream=>50, downstream=>50, codon=>"atg");
+    my @args = opt_get(@_);
+    my $gb = opt_as_gb(shift @args);
+
+    my $upstream = int(opt_val("upstream") / 3);
+    my $downstream = int(opt_val("downstream") / 3);
+    my $codon = opt_val("codon");
+    die ("codon must be 3 letters") if (length($codon) != 3);
+
+    foreach my $cds ($gb->cds()){
+	my $seq = $gb->around_startcodon($cds, $upstream * 3, $downstream * 3, "without");
+
+	for(my $j = 0; $j <= length($seq) - 3; $j +=3){
+	    if(substr($seq, $j, 3) eq $codon){
+		$gb->{$cds}->{on} = 0;
+		last;
+	    }
+	}
+    }
+
+    return $gb->cds();
+}
+
+
 1;
