@@ -6,8 +6,6 @@
 #     Copyright (C) 2001-2007 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
-#   $Id: Skyline.pm,v 1.1 2002/07/30 17:44:27 gaou Exp $
-#
 # G-language GAE is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public
 # License as published by the Free Software Foundation; either
@@ -25,7 +23,7 @@
 # 
 #END_HEADER
 #
-# written by Kazuharu Arakawa <gaou@g-language.org> at
+# written by Kazuharu Arakawa <gaou@sfc.keio.ac.jp> at
 # G-language Project, Institute for Advanced Biosciences, Keio University.
 #
 
@@ -105,6 +103,7 @@ our @EXPORT = qw(
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+    20070707-01 stopped tiling in the x-direction by default
     20070621-01 initial posting
 
 =cut
@@ -138,7 +137,7 @@ sub generateGMap{
     
     
     if($width == $height){
-	system(sprintf("convert %s %s/%s.png", $file, $name, $name));
+	system(sprintf("convert +dither -posterize 16 %s %s/%s.png", $file, $name, $name));
     }else{
 	my ($xdif, $ydif, $size) = (0,0, $width);
 	
@@ -150,7 +149,7 @@ sub generateGMap{
 	    $xdif = int(($height - $width) / 2);
 	}
 	
-	system(sprintf("convert -extent %dx%d -roll +%s+%s %s %s/%s.png", $size, $size, $xdif, $ydif, $file, $name, $name));
+	system(sprintf("convert +dither -posterize 16 -extent %dx%d -roll +%s+%s %s %s/%s.png", $size, $size, $xdif, $ydif, $file, $name, $name));
     }
     
     chdir($name);
@@ -159,8 +158,8 @@ sub generateGMap{
 	my $tiles = 2 ** $i;
 	my $size = $tiles * 256;
 	
-	system(sprintf("convert %s.png -resize %dx%d level$i.png", $name, $size, $size, $i));
-	system("convert level$i.png -crop 256x256 level$i-%d.png");
+	system(sprintf("convert +dither -posterize 16 %s.png -resize %dx%d level$i.png", $name, $size, $size, $i));
+	system("convert +dither -posterize 16 level$i.png -crop 256x256 level$i-%d.png");
 	
 	for(my $y = 1; $y <= $tiles; $y ++){
 	    for(my $x = 1; $x <= $tiles; $x ++){
@@ -223,17 +222,48 @@ sub generateGMap{
 
         var copyright = new GCopyright(1,
                               new GLatLngBounds(new GLatLng(-90, -180), new GLatLng(90, 180)), 0,
-                              "<a href=\\"http://www.g-language.org/\\"><img src=\\"http://restauro-g.iab.keio.ac.jp/Res-Pic/glang.png\\" border=0></a>");
+                              "<a href=\\"http://www.g-language.org/\\" target=\\"_blank\\"><img src=\\"http://restauro-g.iab.keio.ac.jp/Res-Pic/glang.png\\" border=0></a>");
         var copyrightCollection = new GCopyrightCollection();
         copyrightCollection.addCopyright(copyright);
 
+       // Create a new Mercator projection instance 
+        var zoomlevel = $resolution;
+	var projection = new GMercatorProjection(zoomlevel + 1); 
+
+       // add an exposed copy of the tileBounds array 
+	   projection.tileBounds = []; 
+        var c = 1; 
+        for(var d = 0; d <= zoomlevel; d++){ 
+            projection.tileBounds.push(c); 
+            c *= 2 
+	    } 
+
+       // == a method that checks if the y value is in range 
+       // == but *doesnt* wrap the x value == 
+       projection.tileCheckRange = function(a,b,c){ 
+	   var d=this.tileBounds[b]; 
+	   if (a.y<0||a.y>=d) { 
+	       return false; 
+	   } 
+
+	   if(a.x<0||a.x>=d){ 
+	       return false; 
+	   } 
+          return true 
+	  } 
+
+        // == a method that returns the width of the tilespace ==       
+	    projection.getWrapWidth = function(zoom) { 
+		return 99999999999999; 
+	    } 
+
         //create a custom picture layer
         var pic_tileLayers = [ new GTileLayer(copyrightCollection , 0, 17)];
         pic_tileLayers[0].getTileUrl = customGetTileURL;
         pic_tileLayers[0].isPng = function(){ return true};
         pic_tileLayers[0].getOpacity = function() { return 1.0; };
-        var pic_customMap = new GMapType(pic_tileLayers, new GMercatorProjection($level), "View1",
-            {maxResolution:$resolution, minResolution:1, errorMessage:"Data not available"});
+        var pic_customMap = new GMapType(pic_tileLayers, projection, "View1",
+            {maxResolution:zoomlevel, minResolution:1, errorMessage:"Data not available"});
 
         //Now create the custom map. Would normally be G_NORMAL_MAP,G_SATELLITE_MAP,G_HYBRID_MAP
         map = new GMap2(document.getElementById("map"), {mapTypes:[pic_customMap]});
@@ -267,6 +297,7 @@ __HTML__
 
     close(OUT);
 
+    chdir("../");
     msg_error("Google Map View is generated in $name directory.\n");
 }
 
