@@ -6,8 +6,6 @@
 #     Copyright (C) 2001-2007 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
-#   $Id: Skyline.pm,v 1.1 2002/07/30 17:44:27 gaou Exp $
-#
 # G-language GAE is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public
 # License as published by the Free Software Foundation; either
@@ -25,7 +23,7 @@
 # 
 #END_HEADER
 #
-# written by Kazuharu Arakawa <gaou@g-language.org> at
+# written by Kazuharu Arakawa <gaou@sfc.keio.ac.jp> at
 # G-language Project, Institute for Advanced Biosciences, Keio University.
 #
 
@@ -116,7 +114,7 @@ This library is a part of G-language GAE.
     None.
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070607-01 initial posting
@@ -146,7 +144,7 @@ sub mean{
     None.
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070607-01 initial posting
@@ -176,7 +174,7 @@ sub sum{
     None.
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070607-01 initial posting
@@ -206,7 +204,7 @@ sub variance{
     None.
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070607-01 initial posting
@@ -236,7 +234,7 @@ sub standard_deviation{
     None.
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070607-01 initial posting
@@ -266,7 +264,7 @@ sub min{
     None.
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070607-01 initial posting
@@ -296,7 +294,7 @@ sub max{
     None.
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070607-01 initial posting
@@ -326,7 +324,7 @@ sub mindex{
     None.
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070607-01 initial posting
@@ -356,7 +354,7 @@ sub maxdex{
     None.
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070607-01 initial posting
@@ -398,7 +396,7 @@ sub median{
     None.
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070607-01 initial posting
@@ -452,7 +450,7 @@ sub least_squares_fit{
     -sorted    sorted rank coefficient when 1 (default:0)
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070607-01 initial posting
@@ -512,7 +510,7 @@ sub cor{
     -paired    1 for dependent (paired t-test), 0 for independent (default:0)
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070607-01 initial posting
