@@ -25,31 +25,29 @@
 # 
 #END_HEADER
 #
-# written by Kazuharu Arakawa <gaou@g-language.org> at
+# written by Kazuharu Arakawa <gaou@sfc.keio.ac.jp> at
 # G-language Project, Institute for Advanced Biosciences, Keio University.
 #
 
 package SubOpt;
 
 use G::Messenger;
-require G::IO::Bioperl;
-require G::Skyline;
+require G::IO;
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT);
 
 require Exporter;
 
-@ISA = qw(Exporter);
+our @ISA = qw(Exporter);
 
-@EXPORT = qw(
-	     opt_default
-	     opt_val
-	     opt_get
-	     opt_as_gb
+our @EXPORT = qw(
+		 opt_default
+		 opt_val
+		 opt_get
+		 opt_as_gb
 );
 
-$VERSION = '0.10';
+our $VERSION = '0.10';
 
 #::::::::::::::::::::::::::::::
 #          Variables
@@ -73,9 +71,12 @@ sub opt_as_gb {
 
     my $unknown = shift @_;
     my $ref = \$unknown;
-    my $new_gb = new G::Skyline('blessed');
+    my $ref2 = ref $unknown;
+    my $new_gb = new G::IO('blessed');
 
-    if ("$unknown" =~ /\=/){
+    if ($ref2 =~ /Bio::Seq/){
+	return new G::IO($unknown, "bioperl", "no msg");
+    }elsif ("$unknown" =~ /\=/){
 	if (defined $unknown->{SEQ}){
 	    return $unknown;
 	}else{
@@ -119,8 +120,9 @@ sub opt_get{
 	    $data{substr($args[$i],1)} = $args[$i + 1];
 	    $i += 2;
         }else{
-	    if (ref $args[$i] =~ /Bio::Seq/){
-		push(@new_args, G::IO::Bioperl::convert($args[$i]));
+	    my $ref = ref $args[$i];
+	    if ($ref =~ /Bio::Seq/){
+		push(@new_args, new G::IO($args[$i], "bioperl", "no msg"));
 	    }else{
 		push(@new_args, $args[$i]);
 	    }
@@ -233,7 +235,7 @@ SubOpt - Odyssey Subroutine Input API
 
 =head1 AUTHOR
 
-  Kazuharu Gaou Arakawa, gaou@g-language.org
+  Kazuharu Arakawa, gaou@sfc.keio.ac.jp
 
 =head1 SEE ALSO
 
